@@ -170,6 +170,7 @@ SESSION_KEYS = [
 """
 
 
+
 @login_required()
 def update_datasource_select_ajax(request):
     html = update_datasource_select(request)
@@ -1032,7 +1033,6 @@ class GenericEntitiesCreateView(View):
 
     def post(self, *args, **kwargs):
         entity = kwargs['entity']
-
         form = get_custom_generic_entities_form(entity.title())
         form = form(self.request.POST)
         form_text = FullTextForm(self.request.POST, entity=entity.title())
@@ -1045,7 +1045,7 @@ class GenericEntitiesCreateView(View):
             name = self.request.POST["name"]
             ent_class = AbstractEntity.get_entity_class_of_name(entity.title())
             #exists_test = ent_class.objects.filter(name=name)
-            if ent_class == "Person":
+            if ent_class == Person:
                 exists_test = False
             else:
                 exists_test = ent_class.objects.filter(name=name)
@@ -1102,6 +1102,7 @@ class GenericItemCreateView(View):
         if form.is_valid():
             name = self.request.POST["name"]
             success = True
+         
             if not form.Meta.model.objects.filter(name=name).exists():
                 ent = form.save()
                 save_to_created(self.request, ent)
@@ -1404,7 +1405,13 @@ class CustomTableActionButtonView(View):
         was_saved = True
         if year:
             year = int(year)
-        year_written = f"{year}<{year}-06-30>"
+        # added custom test, for christian: add ab min. for schematismus 1811 and 1816
+        if year in [1811, 1816]:
+            year_written = f"ab min. {year}<{year}-06-30>"
+
+        else:
+            year_written = f"{year}<{year}-06-30>"
+        #year_written = f"{year}<{year}-06-30>"
         serialization = get_json_rel(rel_id=rel.id,
                                      rel_class=rel_class.__name__)
         sd = rel.start_date
@@ -1446,9 +1453,13 @@ class CustomTableActionButtonView(View):
             was_saved = False
             succ = True
 
+        ds_pk = self.request.session.get("ds_pk")
+        datasource = DataSource.objects.get(id=ds_pk)
+        page_token = datasource.get_page_token(page_num)
+
         if was_saved:
             save_to_collection(rel, collection)
-            save_citation(rel, citation, page_num)
+            save_citation(rel, citation, page_token)
             save_to_edited(self.request, rel, project, serialization)
 
         if not succ:
